@@ -110,9 +110,13 @@ exportResolveFinalValue <- function(envir) {
 exportExtractElement <- function(where) {
   function(element, name) {
     name <- if (name == "") element else name
-    # we need to make sure that special names, e.g. %*%, ==.foo and names with
-    # whitespaces are parsed correctly
-    regexp <- "^%.*%$|^[[:alnum:][:space:]]+$|^[[:punct:]]{2,}.*$"
+    # we need to make sure that special names, 
+    # - infix operators: %*%, 
+    # - S3 methods for binary operators: ==.foo 
+    # - names with whitespaces 
+    # - single character punctuation: !
+    # are parsed correctly
+    regexp <- "^%.*%$|^[[:alnum:][:space:]]+$|^[[:punct:]]{2,}.*$|^[[:punct:]]$" 
     element <- if (grepl(regexp, element)) paste0("`", element, "`") else element # Exclude Linting
     object <- tryCatch(
       eval(parse(text = element), where, baseenv()),
